pyngsi
======

``pyngsi`` is a Python framework that helps you write a pipeline for your Fiware dataflow.<br>

Writing a NGSI agent that relies on pyngsi avoids all the plumbing so you can focus on writing your own logic to build NGSI entities.<br><br>

*pyngsi has been developed for the needs of the [PIXEL](https://pixel-ports.eu) project, H2020, funded by the EC under Grant Agreement number 769355.*

License
--------

    Copyright (C) 2020-2024 Orange

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.